/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hugegraph.computer.core.sort.sorting;

import java.util.Collection;
import java.util.Comparator;
import java.util.Iterator;

import org.apache.hugegraph.util.E;

public abstract class AbstractInputsSorting<T> implements InputsSorting<T> {

    protected final Iterator<T>[] sources;
    protected final Comparator<? super T> comparator;

    @SuppressWarnings("unchecked")
    public AbstractInputsSorting(Collection<? extends Iterator<T>> sources,
                                 Comparator<? super T> comparator) {
        E.checkNotEmpty(sources, "sources");

        this.sources = sources.toArray(new Iterator[0]);
        this.comparator = comparator;
    }

    protected final int compare(T t1, T t2) {
        @SuppressWarnings("unchecked")
        int result = this.comparator != null ?
                     this.comparator.compare(t1, t2) :
                     ((Comparable<? super T>) t1).compareTo(t2);
        return result;
    }
}
